/*----------------------------------------------------------------------------
 * Name:    Serial.c
 * Purpose: Low Level Serial Routines
 * Note(s): possible defines select the used communication interface:
 *            __DBG_ITM  - ITM SWO interface
 *                       - disabled  (default)
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2014 Keil - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "LPC54xxx.h"                   // Device header
#include "Serial.h"

#ifdef __DBG_ITM
volatile int32_t ITM_RxBuffer = ITM_RXBUFFER_EMPTY;  /*  CMSIS Debug Input    */
#endif


/*----------------------------------------------------------------------------
  Initialize UART pins, Baudrate
 *----------------------------------------------------------------------------*/
void Serial_Initialize (void) {

}


/*----------------------------------------------------------------------------
  Uninitialize UART pins
 *----------------------------------------------------------------------------*/
void Serial_Uninitialize (void) {

}


/*----------------------------------------------------------------------------
  Write character to Serial Port
 *----------------------------------------------------------------------------*/
int Serial_PutChar (int c) {

#if   defined __DBG_ITM
    ITM_SendChar(c);
#endif
  return (c);
}


/*----------------------------------------------------------------------------
  Read character from Serial Port   (blocking read)
 *----------------------------------------------------------------------------*/
int Serial_GetChar (void) {

#if   defined __DBG_ITM
  while (ITM_CheckChar() != 1) __NOP();
  return (ITM_ReceiveChar());
#else
  return (-1);
#endif
}
